"Main interface for workmailmessageflow Client"
from __future__ import annotations

from typing import Dict
from botocore.client import BaseClient
from botocore.exceptions import ClientError as Boto3ClientError

# pylint: disable=import-self
import mypy_boto3_workmailmessageflow.client as client_scope


__all__ = ("Client",)


class Client(BaseClient):
    exceptions: client_scope.Exceptions

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def can_paginate(self, operation_name: str) -> None:
        """
        Check if an operation can be paginated.

        :type operation_name: string
        :param operation_name: The operation name.  This is the same name
            as the method name on the client.  For example, if the
            method name is ``create_foo``, and you'd normally invoke the
            operation as ``client.create_foo(**kwargs)``, if the
            ``create_foo`` operation can be paginated, you can use the
            call ``client.get_paginator("create_foo")``.

        :return: ``True`` if the operation can be paginated,
            ``False`` otherwise.
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def generate_presigned_url(
        self, ClientMethod: str, Params: Dict = None, ExpiresIn: int = 3600, HttpMethod: str = None
    ) -> None:
        """
        Generate a presigned url given a client, its method, and arguments

        :type ClientMethod: string
        :param ClientMethod: The client method to presign for

        :type Params: dict
        :param Params: The parameters normally passed to
            ``ClientMethod``.

        :type ExpiresIn: int
        :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

        :type HttpMethod: string
        :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

        :returns: The presigned url
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_raw_message_content(self, messageId: str) -> Dict:
        """
        Retrieves the raw content of an in-transit email message, in MIME format.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/workmailmessageflow-2019-05-01/GetRawMessageContent>`_

        **Request Syntax**
        ::

          response = client.get_raw_message_content(
              messageId='string'
          )
        :type messageId: string
        :param messageId: **[REQUIRED]**

          The identifier of the email message to retrieve.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'messageContent': StreamingBody()
            }
          **Response Structure**

          - *(dict) --*

            - **messageContent** (:class:`.StreamingBody`) --

              The raw content of the email message, in MIME format.

        """


class Exceptions:
    ClientError: Boto3ClientError
    ResourceNotFoundException: Boto3ClientError



"Main interface for workmailmessageflow service"

from mypy_boto3_workmailmessageflow.client import Client
from mypy_boto3_workmailmessageflow.helpers import boto3_client


__all__ = ("Client", "boto3_client")
